"use client"

import { Box, Card, CardContent, FormControl, FormHelperText, MenuItem, Select, SelectChangeEvent, Typography } from "@mui/material";
import { useState, useEffect } from "react";
import { getGame, getGames } from "@/lib/igdb";
import { IGame } from "@/types/types";
import Image from "next/image";

export default function Sort() {
    const [select, setSelect] = useState('');
    const [games, setGames] = useState<IGame[]>([]);

    useEffect(() => {
        async function fetchGames() {
            //spiele werden über getGames geholt und in den state gesetzt
            const fetchedGames = await getGames();
            setGames(fetchedGames);
        }
        fetchGames();
    }, []);

    const handleChange = (event: SelectChangeEvent) => {
        setSelect(event.target.value);
    };

    const sortGames = () => {
        if (select === "name") {
            // Sortiert die Spiele nach namen (aufsteigend)
            return games.sort((a, b) => a.name.localeCompare(b.name));
        }
        
        // returned unsortierte games
        return games;
    };

    const sortedGames = sortGames();

    return (
        <Box sx={{ position: 'sticky', top: 0 }}>
            <Card variant="outlined">
                <CardContent>
                    <Typography>Filter</Typography>

                    <FormControl fullWidth>
                        <FormHelperText>Sort By</FormHelperText>
                        <Select
                            value={select}
                            onChange={handleChange}
                            displayEmpty
                            inputProps={{ 'aria-label': 'Without label' }}
                        >
                            <MenuItem value="">
                                <em>Any</em>
                            </MenuItem>
                            <MenuItem value="name">Name</MenuItem>
                            
                        </Select>
                    </FormControl>
                </CardContent>
            </Card>

            {/* Zeigt sortierte liste */}
            {sortedGames.map(game => (
                <div key={game.id}>{game.name}</div>
            ))}
        </Box>
    )
}